@@ -1,21 +1,20 @@
-#!/usr/bin/env python
-
 """DSP related functions.
 
 """
 
-
 from __future__ import division, print_function, absolute_import
 
 __author__ = "Marek Rudnicki"
 
+
 import numpy as np
 import scipy.signal as dsp
 
+from thorns.plotting import plot_signal, show
 
 
 def align(a, fs_a, b, fs_b):
-    """Align two signals (a,b) so that they have the same sampling
+    """Align two signals, `a` and `b`, so that they have the same sampling
     frequency (resample to lower fs) and length (trim longer signal).
 
     """
@@ -44,7 +43,10 @@ def align(a, fs_a, b, fs_b):
 
 
 
-def signal_to_noise_ratio_db(signal, noise):
+def snr(signal, noise):
+    """Calculate signal-to-noise ratio in dB given `signal` and
+    `noise`."""
+
     assert signal.shape == noise.shape
 
     snr_db = 20 * np.log10(
@@ -54,18 +56,33 @@ def signal_to_noise_ratio_db(signal, noise):
     return snr_db
 
 
-snr_db = signal_to_noise_ratio_db
-snr = signal_to_noise_ratio_db
 
-
-def root_mean_square(signal):
+def rms(signal):
+    """Calculate root mean squere of a `signal`."""
     return np.sqrt( np.mean(signal**2) )
 
-rms = root_mean_square
 
 
 
 def fft_filter(signal, fs, band):
+    """Filter `signal` using a FFT filter.
+
+    Parameters
+    ----------
+    signal : array_like
+        Input signal.
+    fs : float
+        Sampling frequency of the input signal.
+    band : tuple
+        Tuple with lower and upler cut of frequencies: (lo, hi).
+
+
+    Returns
+    -------
+    array_like
+        Filtered signal.
+
+    """
 
     lo, hi = band
 
@@ -83,6 +100,7 @@ def fft_filter(signal, fs, band):
 
 
 def set_dbspl(signal, dbspl):
+    """Scale the level of `signal` to the given dB_SPL."""
     p0 = 20e-6
     rms = np.sqrt( np.sum(signal**2) / signal.size )
 
@@ -91,13 +109,16 @@ def set_dbspl(signal, dbspl):
     return scalled
 
 
+
 def resample(signal, fs, new_fs):
+    """Resample `signal` from `fs` to `new_fs`."""
     new_signal = dsp.resample(signal, len(signal)*new_fs/fs)
     return new_signal
 
 
 
 def trim(a,b):
+    """Trim the longer vector, so that both have the same length."""
     assert a.ndim == b.ndim == 1
 
     length = min([len(a), len(b)])
@@ -148,7 +169,7 @@ def ramped_tone(
 
     t = np.arange(0, duration, 1/fs)
     s = np.sin(2 * np.pi * t * freq)
-    if dbspl != None:
+    if dbspl is not None:
         s = set_dbspl(s, dbspl)
 
     if ramp != 0:
@@ -300,15 +321,9 @@ def generate_electrical_amplitudes(
 
 
 def t(signal, fs):
-    """
-    Return time vector for the signal.
+    """Return time vector for `signal` with sampling frequency `fs` (Hz)."""
 
-    signal: signal
-    fs: sampling frequency in Hz
-
-    """
-    tmax = (len(signal)-1) / fs
-    return np.linspace(0, tmax, len(signal))
+    return np.arange(0, len(signal)) / fs
 
 
 
@@ -324,6 +339,8 @@ def amplitude_modulated_tone(
 ):
     """Generate amplitude modulated tone.
 
+    Parameters
+    ----------
     fs : float
         Sampling frequency in Hz.
     fm : float
@@ -341,6 +358,12 @@ def amplitude_modulated_tone(
     dbspl : float, optional
         Amplitude of the tone in dB SPL.  If None (default), no scaling.
 
+
+    Returns
+    -------
+    array_like
+        AM signal.
+
     """
     assert ramp < duration/2
     assert 0 <= m <= 1
@@ -349,7 +372,7 @@ def amplitude_modulated_tone(
     t = np.arange(0, duration, 1/fs)
     s = (1 + m*np.sin(2*np.pi*fm*t)) * np.sin(2*np.pi*fc*t)
 
-    if dbspl != None:
+    if dbspl is not None:
         s = set_dbspl(s, dbspl)
 
     if ramp != 0:
@@ -362,6 +385,3 @@ def amplitude_modulated_tone(
     sound = np.concatenate( (s, pad_signal) )
 
     return sound
-
-
-am_tone = amplitude_modulated_tone
